@@ -8,6 +8,8 @@
 #############################
 # Import functions from packages
 
+#' @import catdata
+#'
 #' @importFrom glmnet glmnet
 #' 
 #' @importFrom graphics abline
@@ -64,6 +66,10 @@
 #' @importFrom stats terms
 #' @importFrom stats weighted.mean
 
+#############################
+# Numerical tolerance
+eps_num <- min(sqrt(.Machine$double.eps), 100 * .Machine$double.eps)
+
 #############################
 # Make C code recognisable
 #' @useDynLib smurf, .registration = TRUE 
